import 'package:intl/intl.dart';

import '../Stream.dart';
import '../Tag.dart';

class FloatTag extends Tag {
  double value = 0.0;
  FloatTag();

  FloatTag._(double value) {
    this.value = value;
  }

  static FloatTag valueOf(double value) {
    return FloatTag._(value);
  }

  @override
  void readValue(ByteLayer data) {
    value = data.readFloat();
  }

  @override
  void writeValue(ByteLayer data) {
    data.writeFloat(value);
  }

  @override
  TagType getTagType() {
    return TagType.Float;
  }

  @override
  getValue() {
    return value;
  }

  @override
  void setValue(val) {
    value = val;
  }

  @override
  void prettyPrint(int indent, bool recurse) {
    NumberFormat nf = NumberFormat("###.##", "en_US");
    print(
        "${"".padLeft(indent, '\t')}${Tag.getCanonicalName(getTagType())}: ${nf.format(value)}");
  }

  @override
  void writeStringifiedValue(StringBuilder builder, int indent, bool isList) {
    NumberFormat nf = NumberFormat("###.##", "en_US");
    builder.append(
        "${isList ? "".padLeft(indent, '\t') : ""}${nf.format(value)}f");
  }

  @override
  void readStringifiedValue(StringReader reader) {
    double val = double.parse(reader.readNumber());
    value = val;

    reader.expect("f");
  }
}
